@@ -86,6 +86,7 @@ class ProgressProcess(Process):
             stderr=subprocess.STDOUT,
             stdout=subprocess.PIPE,
             universal_newlines=True,
+            encoding='utf-8',
         )
         self._kill_event = kill_event or Event()
 
@@ -428,7 +429,7 @@ def clean(app_options=None):
     if app_dir == pjoin(HERE, 'core'):
         raise ValueError('Cannot clean the core app')
 
-    if app_options.all:
+    if getattr(app_options, 'all', False):
         logger.info('Removing everything in %s...', app_dir)
         _rmtree_star(app_dir, logger)
     else:
@@ -444,7 +445,7 @@ def clean(app_options=None):
                 logger.info('%s not present, skipping...', name)
 
     logger.info('Success!')
-    if app_options.all or app_options.extensions:
+    if getattr(app_options, 'all', False) or getattr(app_options, 'extensions', False):
         logger.info('All of your extensions have been removed, and will need to be reinstalled')
 
 
@@ -1606,7 +1607,7 @@ class _AppHandler(object):
             metadata = _fetch_package_metadata(self.registry, name, self.logger)
         except URLError:
             return
-        versions = metadata.get('versions', [])
+        versions = metadata.get('versions', {})
 
         # Sort pre-release first, as we will reverse the sort:
         def sort_key(key_value):
@@ -1650,7 +1651,7 @@ class _AppHandler(object):
                 metadata = _fetch_package_metadata(self.registry, name, self.logger)
             except URLError:
                 continue
-            versions = metadata.get('versions', [])
+            versions = metadata.get('versions', {})
 
             # Sort pre-release first, as we will reverse the sort:
             def sort_key(key_value):
@@ -1703,7 +1704,7 @@ class _AppHandler(object):
         except URLError:
             pass
         else:
-            versions = metadata.get('versions', [])
+            versions = metadata.get('versions', {})
 
             # Sort pre-release first, as we will reverse the sort:
             def sort_key(key_value):
